#!/usr/bin/env python3
import argparse
import os
import logging
import subprocess
import sys

SCALEBOT_HOME = "/srv/scalebot"
SCALEBOT_REPO = os.path.join(SCALEBOT_HOME, "repo")


def main():

    parser = argparse.ArgumentParser()

    parser.add_argument('-s', '--syncjobs',
                        help=("This will import jenkins jobs via yaml from \
                                 $SCALEBOT_REPO/jobs/"),
                        required=False,
                        action='store_true')
    parser.add_argument('-d', '--deletejobs',
                        help=("This will Delete all jobs from Hudson, useful \
                              or refreshing job list after branch change."),
                        required=False,
                        action='store_true')

    args = parser.parse_args()

    # If no args specified upon calling tool, dump help and exit
    if len(sys.argv[1:]) == 0:
        parser.print_help()
        parser.exit()

    # Load jenkinsjobs config
    config_ini = '/etc/jenkins_jobs/jenkins_jobs.ini'

    try:
        if args.deletejobs:
            # Delete the jobs completely from Jenkins
            logger.info('Removing Jenkins Jobs from Hudson')
            cmd = subprocess.Popen(["jenkins-jobs", "delete-all"],
                                   stdin=subprocess.PIPE,
                                   stdout=subprocess.PIPE)
            cmd.communicate(input="Y".encode())
            logger.info('Hudson Jobs Deleted')

        if args.syncjobs:
            logger.info('Importing Jenkins Jobs')
            for x in os.listdir('{}/jobs/'.format(SCALEBOT_REPO)):
                subprocess.run(['/usr/local/bin/jenkins-jobs', '--flush-cache',
                                '--conf', config_ini, 'update', '{}/jobs/{}'
                                .format(SCALEBOT_REPO, x)], check=True)
            logger.info('Import Jobs Complete')

    except Exception as e:
        logger.info("Problem with job import")
        logger.info(e)
        return '-1'

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

if __name__ == "__main__":
    sys.exit(main())
